
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.004003
eval "use Test::Spelling 0.12; use Pod::Wordlist::hanekomu; 1" or die $@;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Auth
Charset
Etheridge
Luehrs
Ragwitz
Rolsky
TW
invocant
invocants
stringifying
subclasses
unordered
utf
zh
Stevan
Little
stevan
Infinity
Interactive
Inc
lib
HTTP
Headers
ActionPack
Core
BaseAuthHeader
Authorization
AuthenticationInfo
Base
AcceptCharset
AcceptLanguage
BaseHeaderList
BaseHeaderType
Digest
MediaType
WWWAuthenticate
DateHeader
PriorityList
MediaTypeList
Basic
ContentNegotiation
LinkList
LinkHeader
BaseHeaderWithParams
Util
